@@ -164,7 +164,7 @@ L<http://www.nai.com/>
 
 =head1 AUTHOR
 
-Dianne Skoll (dfs@roaringpenguin.com)
+Dianne Skoll (dianne@skoll.ca)
 
 Dave O'Neill (dmo@roaringpenguin.com)
 
