@@ -117,7 +117,7 @@ L<http://www.sophos.com>
 
 =head1 AUTHORS
 
-Dianne Skoll (dfs@roaringpenguin.com),
+Dianne Skoll (dianne@skoll.ca),
 
 Dave O'Neill (dmo@roaringpenguin.com),
 
